A Python library that downloads case information from U.S. county courts

## Links

- Documentation: [court-scraper.readthedocs.io](https://court-scraper.readthedocs.io/en/latest/)
- GitHub: [github.com/biglocalnews/court-scraper](https://github.com/biglocalnews/court-scraper)
- PyPI: [pypi.org/project/court-scraper/](https://pypi.org/project/court-scraper/)
